package com.agilecontrol.nea.core.control.ejb.command;

import com.agilecontrol.nea.core.control.ejb.Command;
import com.agilecontrol.nea.core.control.event.DefaultWebEvent;
import com.agilecontrol.nea.core.control.event.NDSEventException;
import com.agilecontrol.nea.core.control.util.ValueHolder;
import com.agilecontrol.nea.core.control.web.AttachmentManager;
import com.agilecontrol.nea.core.control.web.WebUtils;
import com.agilecontrol.nea.core.query.QueryEngine;
import com.agilecontrol.nea.core.schema.Column;
import com.agilecontrol.nea.core.schema.Table;
import com.agilecontrol.nea.core.schema.TableManager;
import com.agilecontrol.nea.core.util.ConfigValues;
import com.agilecontrol.nea.util.Attachment;
import com.agilecontrol.nea.util.NDSException;
import com.agilecontrol.nea.util.StringUtils;
import com.agilecontrol.nea.util.Tools;
import com.agilecontrol.nea.util.Validator;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.rmi.RemoteException;
import java.sql.Connection;
import java.util.Vector;
import org.json.JSONObject;

public class SaveAttachmentURL extends Command {

   public static String createURL(int table, int column, String timePart, String fileName, String schema) throws NDSException {
      String url = null;

      try {
         url = "/Attach";
         if(ConfigValues.get("portal.attach.schema", true)) {
            url = url + String.format("/schema/%s", new Object[]{schema});
         }

         url = url + "/table/" + table + "/column/" + column + "/t/" + timePart + "/f/" + URLEncoder.encode(fileName, "UTF-8");
         return url;
      } catch (UnsupportedEncodingException var7) {
         throw new NDSException("Fail to encode " + fileName, var7);
      }
   }

   public static String createURL(int table, int column, int objectId, String fileName, int version, String schema) throws NDSException {
      String fn = null;

      try {
         if(Validator.isNotNull(fileName)) {
            fn = URLEncoder.encode(fileName, "UTF-8");
         } else {
            fn = "";
         }
      } catch (UnsupportedEncodingException var9) {
         throw new NDSException("Fail to encode " + fileName, var9);
      }

      Column col = TableManager.getInstance().getColumn(column);
      String url = "/Attach";
      if(ConfigValues.get("portal.attach.schema", true)) {
         url = url + String.format("/schema/%s", new Object[]{schema});
      }

      if(col.getJSONProps() != null && col.getJSONProps().optBoolean("fixversion", false)) {
         url = url + String.format("/table/%s/column/%s/id/%s/v/%s/f/%s", new Object[]{String.valueOf(table), String.valueOf(column), String.valueOf(objectId), String.valueOf(version), fn});
      } else {
         url = url + String.format("/table/%s/column/%s/id/%s/f/%s", new Object[]{String.valueOf(table), String.valueOf(column), String.valueOf(objectId), fn});
      }

      return url;
   }

   public ValueHolder execute(DefaultWebEvent event) throws NDSException, RemoteException {
      this.helper.checkDirectoryWritePermission(event, this.helper.getOperator(event));
      ValueHolder v = new ValueHolder();
      boolean isUploadFile = Tools.getBoolean(event.getParameterValue("upload"), false);
      String url = "";
      AttachmentManager attm = (AttachmentManager)WebUtils.getServletContextManager().getActor("nea.web.AttachmentManager");
      TableManager manager = TableManager.getInstance();
      Table table = manager.findTable(event.getParameterValue("table"));
      String schema = event.getContext().getUserWeb().getDataSource();
      if(ConfigValues.get("portal.attach.lowercase", false)) {
         schema = schema.toLowerCase();
      }

      Object oCol = event.getParameterValue("column");
      Column col = Validator.isNumber(oCol.toString())?manager.getColumn(Tools.getInt(oCol, -1)):table.getColumn(oCol.toString());
      int objectId = Tools.getInt(event.getParameterValue("objectid"), -1);
      boolean isRest = "Y".equalsIgnoreCase((String)event.getParameterValue("rest", true));
      String t = (String)event.getParameterValue("t");
      String ex;
      if(Validator.isNotNull(t)) {
         ex = (String)event.getParameterValue("filename");
         if(Validator.isNull(ex)) {
            throw new NDSException("缺少参数filename");
         }

         url = createURL(table.getId(), col.getId(), t, ex, schema);
      } else {
         Attachment ex1 = attm.getAttachmentInfo(event.getContext().getUserWeb().getClientDomain() + "/" + AttachmentManager.getSchemaPath(schema) + table.getRealTableName() + "/" + col.getName(), "" + objectId, -1);
         if(isUploadFile) {
            String msg = (String)event.getParameterValue("filename");
            this.logger.debug("*************Attachment" + msg);
            url = createURL(table.getId(), col.getId(), objectId, msg, ex1.getVersion(), schema);
         } else {
            url = (String)event.getParameterValue("fileurl");
         }
      }

      if(objectId != -1) {
         ex = "update " + table.getRealTableName() + " set " + col.getName() + "=\'" + StringUtils.escapeForSQL(url) + "\'";
         if(table.getColumn("modifierid") != null) {
            ex = ex + ", modifierid=" + this.helper.getOperator(event).getId().intValue();
         }

         if(table.getColumn("modifieddate") != null) {
            ex = ex + ", modifieddate=sysdate";
         }

         ex = ex + " where id=" + event.getParameterValue("objectid");
         this.logger.debug("******************sql" + ex);
         QueryEngine msg1 = QueryEngine.getInstance();
         Vector sqls = new Vector();
         sqls.addElement(ex);
         Connection con = event.getContext().getConnection(true);
         this.helper.getOperator(event);

         try {
            msg1.doUpdate(sqls, con);
         } catch (Exception var29) {
            throw new NDSEventException(var29.getMessage());
         } finally {
            try {
               if(con != null) {
                  event.getContext().closeConnection();
               }
            } catch (Exception var27) {
               ;
            }

         }
      }

      if(!isRest) {
         v.put("next-screen", "/nea/core/objext/upload.jsp?table=" + event.getParameterValue("table") + "&column=" + event.getParameterValue("column") + "&objectid=" + event.getParameterValue("objectid") + "&input=" + event.getParameterValue("input"));
      } else {
         v.put("next-screen", "/msgjson");
      }

      v.put("url", url);
      v.put("message", "@additional-links-success@");
      if(isRest) {
         try {
            JSONObject ex2 = new JSONObject();
            JSONObject msg2 = new JSONObject();
            ex2.put("message", msg2);
            msg2.put("url", url);
            v.put("data", ex2);
         } catch (Exception var28) {
            throw new NDSException(var28.getMessage(), var28);
         }
      }

      return v;
   }
}
